@@ -8,11 +8,11 @@ from pymodaq.daq_move.utility_classes import params as daq_move_params
 
 #must be loaded to register proper custom parameter types
 from pyqtgraph.parametertree import Parameter, ParameterTree
-import pyqtgraph.parametertree.parameterTypes as pTypes
-import pymodaq.daq_utils.custom_parameter_tree as custom_tree
+from pymodaq.daq_utils.parameter import ioxml
+from pymodaq.daq_utils.parameter import utils as putils
 
 
-from pymodaq.daq_utils.daq_utils import ThreadCommand, make_enum, getLineInfo
+from pymodaq.daq_utils.daq_utils import ThreadCommand
 from easydict import EasyDict as edict
 from pymodaq.daq_utils.tcp_server_client import TCPClient
 from pymodaq.daq_utils import daq_utils as utils
@@ -366,9 +366,8 @@ class DAQ_Move(Ui_Form, QObject):
                             self.command_tcpip.emit(ThreadCommand('send_info', dict(path=path, param=param)))
 
             elif change == 'parent':
-                if path is not None:
-                    if 'main_settings' not in path:
-                        self.update_settings_signal.emit(edict(path=['detector_settings'], param=param, change=change))
+                if param.name() not in putils.iter_children(self.settings.child('main_settings'), []):
+                    self.update_settings_signal.emit(edict(path=['move_settings'], param=param, change=change))
 
     def connect_tcp_ip(self):
         if self.settings.child('main_settings', 'tcpip', 'connect_server').value():
@@ -411,7 +410,7 @@ class DAQ_Move(Ui_Form, QObject):
             self.thread_status(status)
 
         elif status.command == 'set_info':
-            param_dict = custom_tree.XML_string_to_parameter(status.attributes[1])[0]
+            param_dict = ioxml.XML_string_to_parameter(status.attributes[1])[0]
             param_tmp = Parameter.create(**param_dict)
             param = self.settings.child('move_settings', *status.attributes[0][1:])
 
@@ -432,7 +431,7 @@ class DAQ_Move(Ui_Form, QObject):
             try:
                 self.parent.parent().parent().close() #the dock parent (if any)
             except Exception as e:
-                self.logger.exception(str(e))
+                self.logger.info('No dock parent to close')
 
         except Exception as e:
             icon = QtGui.QIcon()
@@ -458,7 +457,7 @@ class DAQ_Move(Ui_Form, QObject):
             --------
             update_status
         """
-        self.update_status("Timeout occured",wait_time=self.wait_time,log_type="log")
+        self.update_status("Timeout occured", wait_time=self.wait_time)
         self.wait_position_flag=False
 
     def set_enabled_move_buttons(self,enable=False):
@@ -812,8 +811,8 @@ class DAQ_Move_stage(QObject):
             --------
             move_Rel
         """
-        self.target_position=self.current_position+rel_position
-        pos=self.hardware.move_Rel(rel_position)
+        self.target_position = self.current_position + rel_position
+        pos = self.hardware.move_Rel(rel_position)
 
 
     @pyqtSlot(float)
@@ -944,22 +943,25 @@ class DAQ_Move_stage(QObject):
             --------
             update_settings
         """
-        #settings_parameter_dict = edict(path=path,param=param)
-        path=settings_parameter_dict['path']
-        param=settings_parameter_dict['param']
-        if path[0]=='main_settings':
-            if hasattr(self,path[-1]):
-                setattr(self,path[-1],param.value())
+        # settings_parameter_dict = edict(path=path,param=param)
+        path = settings_parameter_dict['path']
+        param = settings_parameter_dict['param']
+        if path[0] == 'main_settings':
+            if hasattr(self, path[-1]):
+                setattr(self, path[-1], param.value())
 
-        elif path[0]=='move_settings':
+        elif path[0] == 'move_settings':
             self.hardware.update_settings(settings_parameter_dict)
 
 
-
+def main():
+    app = QtWidgets.QApplication(sys.argv)
+    Form = QtWidgets.QWidget()
+    prog = DAQ_Move(Form, title="test", preset=[dict(object='Stage_type_combo', method='setCurrentText', value='Mock')],
+                    init=False)
+    Form.show()
+    sys.exit(app.exec_())
 
 
 if __name__ == '__main__':
-    app = QtWidgets.QApplication(sys.argv)
-    Form = QtWidgets.QWidget();prog = DAQ_Move(Form,title="test",preset=[dict(object='Stage_type_combo',method='setCurrentText',value='PI')],init=False);Form.show()
-    #Form1 = QtWidgets.QWidget();prog = DAQ_Move(Form1,title="test1",managers=[dict(object='Stage_type_combo',method='setCurrentText',value='PI')],init=False);Form1.show()
-    sys.exit(app.exec_())
+    main()
