@@ -16,6 +16,7 @@ if 'win32' in sys.platform:
 
 import enum
 import os
+import pkgutil
 import importlib
 import toml
 import logging
@@ -55,17 +56,35 @@ def get_set_local_dir(basename='pymodaq_local'):
                 local_path.mkdir()
     return local_path
 
-def load_config():
-    config_path = get_set_local_dir().joinpath('config.toml')
+def load_config(config_path=None):
+    if not config_path:
+        config_path = get_set_local_dir().joinpath('config.toml')
+    config_base = toml.load(Path(__file__).parent.parent.joinpath('config_template.toml'))
     if not config_path.exists(): #copy the template from pymodaq folder and create one in pymodad's local folder
-        config = toml.load(Path(__file__).parent.parent.joinpath('config_template.toml'))
+        config_path.write_text(toml.dumps(config_base))
+
+    # check if all fields are there
+    config = toml.load(config_path)
+    if check_config(config_base, config):
         config_path.write_text(toml.dumps(config))
-    else:
-        config = toml.load(config_path)
     return config
 
+
+def check_config(config_base, config_local):
+    status = False
+    for key in config_base:
+        if key in config_local:
+            if isinstance(config_base[key], dict):
+                status = status or check_config(config_base[key], config_local[key])
+        else:
+            config_local[key] = config_base[key]
+            status = True
+    return status
+
 config = load_config()
 
+
+
 class JsonConverter:
     def __init__(self):
         super().__init__()
@@ -618,6 +637,24 @@ def recursive_find_files_extension(ini_path, ext, paths=[]):
                 recursive_find_files_extension(entry.path, ext, paths)
     return paths
 
+def recursive_find_expr_in_files(ini_path, exp='make_enum', paths=[],
+                                 filters=['.git', '.idea', '__pycache__', 'build', 'egg', 'documentation']):
+    for child in Path(ini_path).iterdir():
+        if not any(filt in str(child) for filt in filters):
+            if child.is_dir():
+                recursive_find_expr_in_files(child, exp, paths, filters)
+            else:
+                try:
+                    if 'daq_utils.py' in str(child):
+                        print(child)
+                    with child.open('r') as f:
+                        for ind, line in enumerate(f.readlines()):
+                            if exp in line:
+                                paths.append([child, ind])
+                except :
+                    pass
+    return paths
+
 def remove_spaces(string):
     """
     return a string without any white spaces in it
@@ -675,46 +712,6 @@ def elt_as_first_element_dicts(elt_list, match_word='Mock', key='name'):
         plugins = []
     return plugins
 
-def find_in_path(path, mode='daq_move'):
-    """
-        Find the .py files in the given path directory
-
-        =============== =========== ====================================
-        **Parameters**    **Type**   **Description**
-        *path*            string     The path to the directory to check
-        =============== =========== ====================================
-
-        Returns
-        -------
-        String list
-            The list containing all the .py files in the directory.
-    """
-    plugins = []
-    paths = os.listdir(path)
-    for entry in paths:
-        if mode in entry:
-            plugins.append(entry[len(mode) + 1:-3])
-    return plugins
-
-
-def get_names_simple(mode='daq_move'):
-    import pymodaq_plugins
-    base_path = os.path.split(pymodaq_plugins.__file__)[0]
-    plugin_list = []
-    if mode == 'daq_move':
-        plugin_list = find_in_path(os.path.join(base_path, 'daq_move_plugins'), mode)
-    elif mode == 'daq_0Dviewer':
-        plugin_list = find_in_path(os.path.join(base_path, 'daq_viewer_plugins', 'plugins_0D'), mode)
-    elif mode == 'daq_1Dviewer':
-        plugin_list = find_in_path(os.path.join(base_path, 'daq_viewer_plugins', 'plugins_1D'), mode)
-    elif mode == 'daq_2Dviewer':
-        plugin_list = find_in_path(os.path.join(base_path, 'daq_viewer_plugins', 'plugins_2D'), mode)
-    elif mode == 'daq_NDviewer':
-        plugin_list = find_in_path(os.path.join(base_path, 'daq_viewer_plugins', 'plugins_ND'), mode)
-
-    plugins_import = elt_as_first_element(plugin_list, match_word='Mock')
-    return plugins_import
-
 def get_plugins(plugin_type='daq_0Dviewer'):
     """
     Get plugins names as a list
@@ -727,12 +724,11 @@ def get_plugins(plugin_type='daq_0Dviewer'):
     -------
 
     """
+    plugins_import = []
     discovered_plugins = {
         entry_point.name: entry_point.load()
-        for entry_point
-        in pkg_resources.iter_entry_points('pymodaq.plugins')
+        for entry_point in pkg_resources.iter_entry_points('pymodaq.plugins')
     }
-    plugins_import = []
 
     for module in discovered_plugins.values():
         try:
@@ -741,7 +737,10 @@ def get_plugins(plugin_type='daq_0Dviewer'):
             else:
                 submodule = importlib.import_module(f'{module.__name__}.daq_viewer_plugins.plugins_{plugin_type[4:6]}',
                                                     module.__package__)
-            plugin_list = [{'name': mod[len(plugin_type)+1:], 'module': submodule} for mod in dir(submodule) if plugin_type in mod]
+            plugin_list = [{'name': mod[len(plugin_type) + 1:],
+                            'module': submodule} for mod in [mod[1] for
+                                                             mod in pkgutil.iter_modules([submodule.path.parent])]
+                           if plugin_type in mod]
             # check if modules are importable
 
             for mod in plugin_list:
@@ -758,76 +757,6 @@ def get_plugins(plugin_type='daq_0Dviewer'):
     plugins_import = elt_as_first_element_dicts(plugins_import, match_word='Mock', key='name')
     return plugins_import
 
-def get_names(mode):
-    """
-        Get plugins names list from os dir command on plugins folder.
-        The mode arguments specify the directory to list between DAQ_Move
-        and DAQ_Viewer_XD
-
-        =============== =========== ====================================================================
-        **Parameters**    **Type**   **Description**
-        *mode*            *string    The plugins directory to check between :
-                                        * *DAQ_Move* : Check for DAQ_Move controllers plugins
-                                        * *DAQ_Viewer_0D* : Chack for DAQ_Viewer\0D controllers plugins
-                                        * *DAQ_Viewer_1D* : Chack for DAQ_Viewer\1D controllers plugins
-                                        * *DAQ_Viewer_2D* : Chack for DAQ_Viewer\2D controllers plugins
-        =============== =========== ====================================================================
-
-        Returns
-        -------
-        String list
-            The list containing all the present plugins names.
-    """
-    plugin_list = get_names_simple(mode)
-    if mode == 'daq_move':
-        subpack = 'pymodaq_plugins.daq_move_plugins'
-    elif mode == 'daq_0Dviewer':
-        subpack = 'pymodaq_plugins.daq_viewer_plugins.plugins_0D'
-    elif mode == 'daq_1Dviewer':
-        subpack = 'pymodaq_plugins.daq_viewer_plugins.plugins_1D'
-    elif mode == 'daq_2Dviewer':
-        subpack = 'pymodaq_plugins.daq_viewer_plugins.plugins_2D'
-    elif mode == 'daq_NDviewer':
-        subpack = 'pymodaq_plugins.daq_viewer_plugins.plugins_ND'
-
-    # check if modules are importable
-    plugins_import = []
-    for mod in plugin_list:
-        try:
-            importlib.import_module(f'.{mode}_' + mod, subpack)
-            plugins_import.append(mod)
-        except:
-            pass
-
-    return plugins_import
-
-
-def make_enum(mode):
-    """
-        Custom class generator.
-        Create a dynamic enum containing the plugins folder file names.
-
-        Returns
-        -------
-        Instance of Enum
-            The enum object representing loaded plugins
-    """
-    names = get_names(mode)
-    values = {}
-    for i in range(0, len(names)):
-        values.update({names[i]: i + 1})
-    meta = type(enum.Enum)
-    bases = (enum.Enum,)
-    dict = meta.__prepare__(names, bases)
-    dict.update({'names': get_names})
-    for key, value in values.items():
-        dict[key] = value
-    if mode == 'daq_move':
-        return meta(mode + '_Stage_type', bases, dict)
-    else:
-        return meta(mode + '_Type', bases, dict)
-
-
 def check_vals_in_iterable(iterable1, iterable2):
     assert len(iterable1) == len(iterable2)
     iterable1 = list(iterable1)  # so the assertion below is valid for any kind of iterable, list, tuple, ndarray...
@@ -1211,7 +1140,7 @@ def linspace_step(start, stop, step):
     return np.linspace(start, new_stop, Nsteps)
 
 
-def find_dict_in_list_from_key_val(dicts, key, value):
+def find_dict_in_list_from_key_val(dicts, key, value, return_index=False):
     """ lookup within a list of dicts. Look for the dict within the list which has the correct key, value pair
 
     Parameters
@@ -1225,11 +1154,17 @@ def find_dict_in_list_from_key_val(dicts, key, value):
     dict: if found otherwose returns None
     """
 
-    for dict in dicts:
-        if key in dict:
-            if dict[key] == value:
-                return dict
-    return None
+    for ind, d in enumerate(dicts):
+        if key in d:
+            if d[key] == value:
+                if return_index:
+                    return d, ind
+                else:
+                    return d
+    if return_index:
+        return None, -1
+    else:
+        return None
 
 def find_index(x, threshold):
     """
@@ -1523,4 +1458,6 @@ def ift2(x, dim=(-2, -1)):
 
 
 if __name__ == '__main__':
-    pass
+    paths = recursive_find_expr_in_files('C:\\Users\\weber\\Labo\\Programmes Python\\PyMoDAQ_Git', 'custom_parameter')
+    for p in paths:
+        print(str(p))
