@@ -3,16 +3,18 @@
 
 import sys
 import datetime
+import subprocess
 import pickle
 import logging
 from pathlib import Path
 
 from PyQt5 import QtGui, QtWidgets, QtCore
-from PyQt5.QtCore import Qt,QObject, pyqtSlot, QThread, pyqtSignal, QLocale
+from PyQt5.QtCore import Qt, QObject, pyqtSlot, QThread, pyqtSignal, QLocale
 
+from pymodaq.daq_utils.parameter import utils as putils
 from pyqtgraph.dockarea import Dock
 from pyqtgraph.parametertree import Parameter, ParameterTree
-import pymodaq.daq_utils.custom_parameter_tree as custom_tree# to be placed after importing Parameter
+import pymodaq.daq_utils.parameter.pymodaq_ptypes as ptypes# to be placed after importing Parameter
 
 from pymodaq.daq_utils import daq_utils as utils
 logger = utils.set_logger(utils.get_module_name(__file__))
@@ -29,6 +31,9 @@ from pymodaq.daq_move.daq_move_main import DAQ_Move
 from pymodaq.daq_viewer.daq_viewer_main import DAQ_Viewer
 from pymodaq.daq_scan import DAQ_Scan
 from pymodaq.daq_logger import DAQ_Logger
+from pymodaq_plugin_manager.manager import PluginManager
+from pymodaq_plugin_manager.validate import get_pypi_pymodaq
+from packaging import version as version_mod
 
 config = utils.load_config()
 
@@ -93,6 +98,9 @@ class DashBoard(QObject):
 
         logger.info('Dashboard Initialized')
 
+        if config['general']['check_version']:
+            self.check_version(show=False)
+
     def set_preset_path(self, path):
         self.preset_path = path
         self.set_extra_preset_params(self.extra_params)
@@ -166,7 +174,9 @@ class DashBoard(QObject):
         self.file_menu.addAction('Show configuration file', self.show_config)
         self.file_menu.addSeparator()
         quit_action = self.file_menu.addAction('Quit')
+        restart_action = self.file_menu.addAction('Restart')
         quit_action.triggered.connect(self.quit_fun)
+        restart_action.triggered.connect(self.restart_fun)
 
         self.settings_menu = menubar.addMenu('Settings')
         docked_menu = self.settings_menu.addMenu('Docked windows')
@@ -267,10 +277,22 @@ class DashBoard(QObject):
         action_help.triggered.connect(self.show_help)
         action_help.setShortcut(QtCore.Qt.Key_F1)
 
-        self.overshoot_menu.setEnabled(False)
-        self.roi_menu.setEnabled(False)
-        self.remote_menu.setEnabled(False)
-        self.actions_menu.setEnabled(False)
+        help_menu.addSeparator()
+        action_update = help_menu.addAction('Check Version')
+        action_update.triggered.connect(lambda: self.check_version(True))
+
+        action_plugin_manager = help_menu.addAction('Plugin Manager')
+        action_plugin_manager.triggered.connect(self.start_plugin_manager)
+
+    def start_plugin_manager(self):
+        self.win_plug_manager = QtWidgets.QMainWindow()
+        self.win_plug_manager.setWindowTitle('PyMoDAQ Plugin Manager')
+        widget = QtWidgets.QWidget()
+        self.win_plug_manager.setCentralWidget(widget)
+        self.plugin_manager = PluginManager(widget)
+        self.plugin_manager.quit_signal.connect(self.quit_fun)
+        self.plugin_manager.restart_signal.connect(self.restart_fun)
+        self.win_plug_manager.show()
 
     def create_menu_slot(self, filename):
         return lambda: self.set_preset_mode(filename)
@@ -355,20 +377,31 @@ class DashBoard(QObject):
         try:
             path = gutils.select_file(start_path=self.preset_path, save=False, ext='xml')
             if path != '':
-                self.preset_manager.set_file_preset(path)
+                modified = self.preset_manager.set_file_preset(path)
 
-                if self.detector_modules != []:
-                    mssg = QtWidgets.QMessageBox()
-                    mssg.setText('You have to restart the application to take the modifications into account! Quitting the application...')
-                    mssg.exec()
-
-                    self.quit_fun()
+                if modified:
+                    self.remove_preset_related_files(path.name)
+                    if self.detector_modules:
+                        mssg = QtWidgets.QMessageBox()
+                        mssg.setText('You have to restart the application to take the modifications into account!\n\n'
+                                     'The related files: ROI, Layout, Overshoot and Remote will be deleted'
+                                     ' if existing!\n\n'
+                                     'Quitting the application...')
+                        mssg.exec()
+                        self.restart_fun()
 
             else:  # cancel
                 pass
         except Exception as e:
             logger.exception(str(e))
 
+    def remove_preset_related_files(self, name):
+        utils.get_set_roi_path().joinpath(name).unlink(missing_ok=True)
+        utils.get_set_layout_path().joinpath(name).unlink(missing_ok=True)
+        utils.get_set_overshoot_path().joinpath(name).unlink(missing_ok=True)
+        utils.get_set_remote_path().joinpath(name).unlink(missing_ok=True)
+
+
     def quit_fun(self):
         """
             Quit the current instance of DAQ_scan and close on cascade move and detector modules.
@@ -415,6 +448,20 @@ class DashBoard(QObject):
         except Exception as e:
             logger.exception(str(e))
 
+
+    def restart_fun(self, ask=False):
+        ret = False
+        mssg = QtWidgets.QMessageBox()
+        if ask:
+            mssg.setText('You have to restart the application to take the modifications into account!')
+            mssg.setInformativeText("Do you want to restart?")
+            mssg.setStandardButtons(mssg.Ok | mssg.Cancel)
+            ret = mssg.exec()
+
+        if ret == mssg.Ok or not ask:
+            self.quit_fun()
+            subprocess.call([sys.executable, __file__])
+
     def load_layout_state(self, file=None):
         """
             Load and restore a layout state from the select_file obtained pathname file.
@@ -480,10 +527,7 @@ class DashBoard(QObject):
             (Object list, Object list) tuple
                 The updated (Move modules list, Detector modules list).
 
-            See Also
-            --------
-            custom_tree.XML_file_to_parameter, set_param_from_param, stop_moves, update_status,DAQ_Move_main.daq_move, DAQ_viewer_main.daq_viewer
-        """
+           """
         move_modules = []
         detector_modules = []
         if not isinstance(filename, Path):
@@ -511,7 +555,7 @@ class DashBoard(QObject):
                 if self.preset_manager.preset_params.child(('use_pid')).value():
                     self.open_PID()
                     QtWidgets.QApplication.processEvents()
-                    for child in custom_tree.iter_children_params(self.preset_manager.preset_params.child(('pid_settings')), []):
+                    for child in putils.iter_children_params(self.preset_manager.preset_params.child(('pid_settings')), []):
                         preset_path = self.preset_manager.preset_params.child(('pid_settings')).childPath(child)
                         self.pid_controller.settings.child(*preset_path).setValue(child.value())
 
@@ -523,10 +567,10 @@ class DashBoard(QObject):
             #################################################################
             ###### sort plugins by IDs and within the same IDs by Master and Slave status
             plugins = []
-            if isinstance(self.preset_manager.preset_params.child(('Moves')).children()[0], custom_tree.GroupParameterCustom):
+            if isinstance(self.preset_manager.preset_params.child(('Moves')).children()[0], ptypes.GroupParameterCustom):
                 plugins += [{'type': 'move', 'value': child} for child in
                            self.preset_manager.preset_params.child(('Moves')).children()]
-            if isinstance(self.preset_manager.preset_params.child(('Detectors')).children()[0], custom_tree.GroupParameterCustom):
+            if isinstance(self.preset_manager.preset_params.child(('Detectors')).children()[0], ptypes.GroupParameterCustom):
                 plugins += [{'type': 'det', 'value': child} for child in
                             self.preset_manager.preset_params.child(('Detectors')).children()]
 
@@ -985,7 +1029,7 @@ class DashBoard(QObject):
 
     def update_init_tree(self):
         for act in self.move_modules:
-            if act.title not in custom_tree.iter_children(self.settings.child(('actuators')), []):
+            if act.title not in putils.iter_children(self.settings.child(('actuators')), []):
                 title = act.title
                 name = ''.join(title.split())  # remove empty spaces
                 self.settings.child(('actuators')).addChild(
@@ -994,7 +1038,7 @@ class DashBoard(QObject):
                 self.settings.child('actuators', name).setValue(act.initialized_state)
 
         for act in self.detector_modules:
-            if act.title not in custom_tree.iter_children(self.settings.child(('detectors')), []):
+            if act.title not in putils.iter_children(self.settings.child(('detectors')), []):
                 title = act.title
                 name = ''.join(title.split())  # remove empty spaces
                 self.settings.child(('detectors')).addChild(
@@ -1025,9 +1069,8 @@ class DashBoard(QObject):
         webbrowser.open(logging.getLogger('pymodaq').handlers[0].baseFilename)
 
     def show_config(self):
-        import webbrowser
-        webbrowser.open(str(utils.get_set_local_dir().joinpath('config.toml')))
-
+        config = gutils.TreeFromToml()
+        config.show_dialog()
 
     def setupUI(self):
 
@@ -1069,7 +1112,10 @@ class DashBoard(QObject):
         #creating the menubar
         self.menubar = self.mainwindow.menuBar()
         self.create_menu(self.menubar)
-
+        self.overshoot_menu.setEnabled(False)
+        self.roi_menu.setEnabled(False)
+        self.remote_menu.setEnabled(False)
+        self.actions_menu.setEnabled(False)
 #        connecting
         self.status_signal[str].connect(self.add_status)
 
@@ -1098,9 +1144,6 @@ class DashBoard(QObject):
             *changes*         tuple list                         Contain the (param,changes,info) list listing the changes made
             =============== =================================== ================================================================
 
-            See Also
-            --------
-            change_viewer, daq_utils.custom_parameter_tree.iter_children
         """
 
         for param, change, data in changes:
@@ -1122,6 +1165,33 @@ class DashBoard(QObject):
         self.splash_sc.setVisible(True)
         self.splash_sc.showMessage("PyMoDAQ version {:}\nModular Acquisition with Python\nWritten by Sébastien Weber".format(get_version()), QtCore.Qt.AlignRight, QtCore.Qt.white)
 
+
+    def check_version(self, show=True):
+        try:
+            current_version = version_mod.parse(get_version())
+            available_version = [version_mod.parse(ver['version']) for ver in get_pypi_pymodaq()]
+            msgBox = QtWidgets.QMessageBox()
+            if max(available_version) > current_version:
+                msgBox.setText(f"A new version of PyMoDAQ is available, {str(max(available_version))}!")
+                msgBox.setInformativeText("Do you want to install it?")
+                msgBox.setStandardButtons(msgBox.Ok | msgBox.Cancel)
+                msgBox.setDefaultButton(msgBox.Ok)
+
+                ret = msgBox.exec()
+
+                if ret == msgBox.Ok:
+                    command = [sys.executable, '-m', 'pip', 'install', f'pymodaq=={str(max(available_version))}']
+                    subprocess.Popen(command)
+
+                    self.restart_fun()
+            else:
+                if show:
+                    msgBox.setText(f"Your version of PyMoDAQ, {str(current_version)}, is up to date!")
+                    ret = msgBox.exec()
+        except Exception as e:
+            logger.exception("Error while checking the available PyMoDAQ version")
+            
+
     def show_file_attributes(self, type_info='dataset'):
         """
             Switch the type_info value.
@@ -1140,10 +1210,6 @@ class DashBoard(QObject):
                                             * dataset
                                             * managers
             =============== =========== ====================================
-
-            See Also
-            --------
-            custom_tree.parameter_to_xml_file, create_menu
         """
         dialog = QtWidgets.QDialog()
         vlayout = QtWidgets.QVBoxLayout()
@@ -1192,7 +1258,7 @@ class DashBoard(QObject):
             pass
 
 
-if __name__ == '__main__':
+def main():
     app = QtWidgets.QApplication(sys.argv)
     win = QtWidgets.QMainWindow()
     area = gutils.DockArea()
@@ -1204,3 +1270,6 @@ if __name__ == '__main__':
     prog = DashBoard(area)
     sys.exit(app.exec_())
 
+if __name__ == '__main__':
+    main()
+
